![logo](logo-white-words.png "TackleBox")
### A framework for improved handling of PyTorch module hooks

## Installation
```shell
pip install tacklebox
```
## Usage

#### Defining hook functions
```python
from tacklebox.hook_management import HookManager


```
